==> birder-0.0.5a82-py3-none-any.whl: birder/net/__init__.py <==
from birder.net.alexnet import AlexNet
from birder.net.biformer import BiFormer
from birder.net.cait import CaiT
from birder.net.coat import CoaT
from birder.net.convmixer import ConvMixer
from birder.net.convnext_v1 import ConvNeXt_v1
from birder.net.convnext_v2 import ConvNeXt_v2
from birder.net.crossvit import CrossViT
from birder.net.cspnet import CSPNet
from birder.net.cswin_transformer import CSWin_Transformer
from birder.net.darknet import Darknet
from birder.net.davit import DaViT
from birder.net.deit import DeiT
from birder.net.deit3 import DeiT3
from birder.net.densenet import DenseNet
from birder.net.dpn import DPN
from birder.net.edgenext import EdgeNeXt
from birder.net.edgevit import EdgeViT
from birder.net.efficientformer_v1 import EfficientFormer_v1
from birder.net.efficientformer_v2 import EfficientFormer_v2
from birder.net.efficientnet_lite import EfficientNet_Lite
from birder.net.efficientnet_v1 import EfficientNet_v1
from birder.net.efficientnet_v2 import EfficientNet_v2
from birder.net.efficientvit_mit import EfficientViT_MIT
from birder.net.efficientvit_msft import EfficientViT_MSFT
from birder.net.fasternet import FasterNet
from birder.net.fastvit import FastViT
from birder.net.focalnet import FocalNet
from birder.net.ghostnet_v1 import GhostNet_v1
from birder.net.ghostnet_v2 import GhostNet_v2
from birder.net.hiera import Hiera
from birder.net.hieradet import HieraDet
from birder.net.iformer import iFormer
from birder.net.inception_next import Inception_NeXt
from birder.net.inception_resnet_v2 import Inception_ResNet_v2
from birder.net.inception_v3 import Inception_v3
from birder.net.inception_v4 import Inception_v4
from birder.net.levit import LeViT
from birder.net.maxvit import MaxViT
from birder.net.metaformer import MetaFormer
from birder.net.mnasnet import MNASNet
from birder.net.mobilenet_v1 import MobileNet_v1
from birder.net.mobilenet_v2 import MobileNet_v2
from birder.net.mobilenet_v3_large import MobileNet_v3_Large
from birder.net.mobilenet_v3_small import MobileNet_v3_Small
from birder.net.mobilenet_v4 import MobileNet_v4
from birder.net.mobilenet_v4_hybrid import MobileNet_v4_Hybrid
from birder.net.mobileone import MobileOne
from birder.net.mobilevit_v1 import MobileViT_v1
from birder.net.mobilevit_v2 import MobileViT_v2
from birder.net.moganet import MogaNet
from birder.net.mvit_v2 import MViT_v2
from birder.net.nextvit import NextViT
from birder.net.nfnet import NFNet
from birder.net.pit import PiT
from birder.net.pvt_v1 import PVT_v1
from birder.net.pvt_v2 import PVT_v2
from birder.net.rdnet import RDNet
from birder.net.regnet import RegNet
from birder.net.repghost import RepGhost
from birder.net.repvgg import RepVgg
from birder.net.resmlp import ResMLP
from birder.net.resnest import ResNeSt
from birder.net.resnet_v1 import ResNet_v1
from birder.net.resnet_v2 import ResNet_v2
from birder.net.resnext import ResNeXt
from birder.net.se_resnet_v1 import SE_ResNet_v1
from birder.net.se_resnet_v2 import SE_ResNet_v2
from birder.net.se_resnext import SE_ResNeXt
from birder.net.sequencer2d import Sequencer2d
from birder.net.shufflenet_v1 import ShuffleNet_v1
from birder.net.shufflenet_v2 import ShuffleNet_v2
from birder.net.simple_vit import Simple_ViT
from birder.net.squeezenet import SqueezeNet
from birder.net.squeezenext import SqueezeNext
from birder.net.swin_transformer_v1 import Swin_Transformer_v1
from birder.net.swin_transformer_v2 import Swin_Transformer_v2
from birder.net.tiny_vit import Tiny_ViT
from birder.net.uniformer import UniFormer
from birder.net.van import VAN
from birder.net.vgg import Vgg
from birder.net.vgg_reduced import Vgg_Reduced
from birder.net.vit import ViT
from birder.net.vit_sam import ViT_SAM
from birder.net.vitreg import ViTReg4
from birder.net.wide_resnet import Wide_ResNet
from birder.net.xception import Xception
from birder.net.xcit import XCiT

__all__ = [
    "AlexNet",
    "BiFormer",
    "CaiT",
    "CoaT",
    "ConvMixer",
    "ConvNeXt_v1",
    "ConvNeXt_v2",
    "CrossViT",
    "CSPNet",
    "CSWin_Transformer",
    "Darknet",
    "DaViT",
    "DeiT",
    "DeiT3",
    "DenseNet",
    "DPN",
    "EdgeNeXt",
    "EdgeViT",
    "EfficientFormer_v1",
    "EfficientFormer_v2",
    "EfficientNet_Lite",
    "EfficientNet_v1",
    "EfficientNet_v2",
    "EfficientViT_MIT",
    "EfficientViT_MSFT",
    "FasterNet",
    "FastViT",
    "FocalNet",
    "GhostNet_v1",
    "GhostNet_v2",
    "Hiera",
    "HieraDet",
    "iFormer",
    "Inception_NeXt",
    "Inception_ResNet_v2",
    "Inception_v3",
    "Inception_v4",
    "LeViT",
    "MaxViT",
    "MetaFormer",
    "MNASNet",
    "MobileNet_v1",
    "MobileNet_v2",
    "MobileNet_v3_Large",
    "MobileNet_v3_Small",
    "MobileNet_v4",
    "MobileNet_v4_Hybrid",
    "MobileOne",
    "MobileViT_v1",
    "MobileViT_v2",
    "MogaNet",
    "MViT_v2",
    "NextViT",
    "NFNet",
    "PiT",
    "PVT_v1",
    "PVT_v2",
    "RDNet",
    "RegNet",
    "RepGhost",
    "RepVgg",
    "ResMLP",
    "ResNeSt",
    "ResNet_v1",
    "ResNet_v2",
    "ResNeXt",
    "SE_ResNet_v1",
    "SE_ResNet_v2",
    "SE_ResNeXt",
    "Sequencer2d",
    "ShuffleNet_v1",
    "ShuffleNet_v2",
    "Simple_ViT",
    "SqueezeNet",
    "SqueezeNext",
    "Swin_Transformer_v1",
    "Swin_Transformer_v2",
    "Tiny_ViT",
    "UniFormer",
    "VAN",
    "Vgg",
    "Vgg_Reduced",
    "ViT",
    "ViT_SAM",
    "ViTReg4",
    "Wide_ResNet",
    "Xception",
    "XCiT",
]

==> birder-0.0.7a0-py3-none-any.whl: birder/net/__init__.py <==
from birder.net.alexnet import AlexNet
from birder.net.biformer import BiFormer
from birder.net.cait import CaiT
from birder.net.cas_vit import CAS_ViT
from birder.net.coat import CoaT
from birder.net.conv2former import Conv2Former
from birder.net.convmixer import ConvMixer
from birder.net.convnext_v1 import ConvNeXt_v1
from birder.net.convnext_v2 import ConvNeXt_v2
from birder.net.crossformer import CrossFormer
from birder.net.crossvit import CrossViT
from birder.net.cspnet import CSPNet
from birder.net.cswin_transformer import CSWin_Transformer
from birder.net.darknet import Darknet
from birder.net.davit import DaViT
from birder.net.deit import DeiT
from birder.net.deit3 import DeiT3
from birder.net.densenet import DenseNet
from birder.net.dpn import DPN
from birder.net.edgenext import EdgeNeXt
from birder.net.edgevit import EdgeViT
from birder.net.efficientformer_v1 import EfficientFormer_v1
from birder.net.efficientformer_v2 import EfficientFormer_v2
from birder.net.efficientnet_lite import EfficientNet_Lite
from birder.net.efficientnet_v1 import EfficientNet_v1
from birder.net.efficientnet_v2 import EfficientNet_v2
from birder.net.efficientvit_mit import EfficientViT_MIT
from birder.net.efficientvit_msft import EfficientViT_MSFT
from birder.net.fasternet import FasterNet
from birder.net.fastvit import FastViT
from birder.net.focalnet import FocalNet
from birder.net.ghostnet_v1 import GhostNet_v1
from birder.net.ghostnet_v2 import GhostNet_v2
from birder.net.groupmixformer import GroupMixFormer
from birder.net.hiera import Hiera
from birder.net.hieradet import HieraDet
from birder.net.hornet import HorNet
from birder.net.iformer import iFormer
from birder.net.inception_next import Inception_NeXt
from birder.net.inception_resnet_v1 import Inception_ResNet_v1
from birder.net.inception_resnet_v2 import Inception_ResNet_v2
from birder.net.inception_v3 import Inception_v3
from birder.net.inception_v4 import Inception_v4
from birder.net.levit import LeViT
from birder.net.maxvit import MaxViT
from birder.net.metaformer import MetaFormer
from birder.net.mnasnet import MNASNet
from birder.net.mobilenet_v1 import MobileNet_v1
from birder.net.mobilenet_v2 import MobileNet_v2
from birder.net.mobilenet_v3_large import MobileNet_v3_Large
from birder.net.mobilenet_v3_small import MobileNet_v3_Small
from birder.net.mobilenet_v4 import MobileNet_v4
from birder.net.mobilenet_v4_hybrid import MobileNet_v4_Hybrid
from birder.net.mobileone import MobileOne
from birder.net.mobilevit_v1 import MobileViT_v1
from birder.net.mobilevit_v2 import MobileViT_v2
from birder.net.moganet import MogaNet
from birder.net.mvit_v2 import MViT_v2
from birder.net.nextvit import NextViT
from birder.net.nfnet import NFNet
from birder.net.pit import PiT
from birder.net.pvt_v1 import PVT_v1
from birder.net.pvt_v2 import PVT_v2
from birder.net.rdnet import RDNet
from birder.net.regionvit import RegionViT
from birder.net.regnet import RegNet
from birder.net.regnet_z import RegNet_Z
from birder.net.repghost import RepGhost
from birder.net.repvgg import RepVgg
from birder.net.repvit import RepViT
from birder.net.resmlp import ResMLP
from birder.net.resnest import ResNeSt
from birder.net.resnet_v1 import ResNet_v1
from birder.net.resnet_v2 import ResNet_v2
from birder.net.resnext import ResNeXt
from birder.net.rope_deit3 import RoPE_DeiT3
from birder.net.rope_vit import RoPE_ViT
from birder.net.se_resnet_v1 import SE_ResNet_v1
from birder.net.se_resnet_v2 import SE_ResNet_v2
from birder.net.se_resnext import SE_ResNeXt
from birder.net.sequencer2d import Sequencer2d
from birder.net.shufflenet_v1 import ShuffleNet_v1
from birder.net.shufflenet_v2 import ShuffleNet_v2
from birder.net.simple_vit import Simple_ViT
from birder.net.smt import SMT
from birder.net.squeezenet import SqueezeNet
from birder.net.squeezenext import SqueezeNext
from birder.net.starnet import StarNet
from birder.net.swin_transformer_v1 import Swin_Transformer_v1
from birder.net.swin_transformer_v2 import Swin_Transformer_v2
from birder.net.tiny_vit import Tiny_ViT
from birder.net.transnext import TransNeXt
from birder.net.uniformer import UniFormer
from birder.net.van import VAN
from birder.net.vgg import Vgg
from birder.net.vgg_reduced import Vgg_Reduced
from birder.net.vit import ViT
from birder.net.vit_sam import ViT_SAM
from birder.net.wide_resnet import Wide_ResNet
from birder.net.xception import Xception
from birder.net.xcit import XCiT

__all__ = [
    "AlexNet",
    "BiFormer",
    "CaiT",
    "CAS_ViT",
    "CoaT",
    "Conv2Former",
    "ConvMixer",
    "ConvNeXt_v1",
    "ConvNeXt_v2",
    "CrossFormer",
    "CrossViT",
    "CSPNet",
    "CSWin_Transformer",
    "Darknet",
    "DaViT",
    "DeiT",
    "DeiT3",
    "DenseNet",
    "DPN",
    "EdgeNeXt",
    "EdgeViT",
    "EfficientFormer_v1",
    "EfficientFormer_v2",
    "EfficientNet_Lite",
    "EfficientNet_v1",
    "EfficientNet_v2",
    "EfficientViT_MIT",
    "EfficientViT_MSFT",
    "FasterNet",
    "FastViT",
    "FocalNet",
    "GhostNet_v1",
    "GhostNet_v2",
    "GroupMixFormer",
    "Hiera",
    "HieraDet",
    "HorNet",
    "iFormer",
    "Inception_NeXt",
    "Inception_ResNet_v1",
    "Inception_ResNet_v2",
    "Inception_v3",
    "Inception_v4",
    "LeViT",
    "MaxViT",
    "MetaFormer",
    "MNASNet",
    "MobileNet_v1",
    "MobileNet_v2",
    "MobileNet_v3_Large",
    "MobileNet_v3_Small",
    "MobileNet_v4",
    "MobileNet_v4_Hybrid",
    "MobileOne",
    "MobileViT_v1",
    "MobileViT_v2",
    "MogaNet",
    "MViT_v2",
    "NextViT",
    "NFNet",
    "PiT",
    "PVT_v1",
    "PVT_v2",
    "RDNet",
    "RegionViT",
    "RegNet",
    "RegNet_Z",
    "RepGhost",
    "RepVgg",
    "RepViT",
    "ResMLP",
    "ResNeSt",
    "ResNet_v1",
    "ResNet_v2",
    "ResNeXt",
    "RoPE_DeiT3",
    "RoPE_ViT",
    "SE_ResNet_v1",
    "SE_ResNet_v2",
    "SE_ResNeXt",
    "Sequencer2d",
    "ShuffleNet_v1",
    "ShuffleNet_v2",
    "Simple_ViT",
    "SMT",
    "SqueezeNet",
    "SqueezeNext",
    "StarNet",
    "Swin_Transformer_v1",
    "Swin_Transformer_v2",
    "Tiny_ViT",
    "TransNeXt",
    "UniFormer",
    "VAN",
    "Vgg",
    "Vgg_Reduced",
    "ViT",
    "ViT_SAM",
    "Wide_ResNet",
    "Xception",
    "XCiT",
]
